@@ -160,11 +160,11 @@ def get_from_ecef(ECEF_DATA: Dict[str, Dict[str,float]]
     y = None
     z = None
     try:
-        ecef = ECEF_DATA['ECEF']
-        if 'X' in ecef:
-            x = ecef['X']
-            y = ecef['Y']
-            z = ecef['Z']
+        ecef = ECEF_DATA.get('ecef', ECEF_DATA.get('ECEF'))
+        if 'x' in ecef:
+            x = ecef.get('x') 
+            y = ecef.get('y')  
+            z = ecef.get('z') 
         elif 'X_POS' in ecef:
             x = ecef['X_POS']
             y = ecef['Y_POS']
